"""
motor_controller controller

A simple controller to set the target of a robot
"""

import csv
import os
from controller import Robot
import numpy as np

import robots

# Setting parameters from environment variables
robot_name = os.environ.get('ROBOT_NAME', 'RobotRRR')
robot_targets = {
    'RobotRT': [1.57, 0.1],
    'RobotRRR': [1.57, 1.57, 1.57]
}
targets = robot_targets[robot_name]

model = robots.getRobotModel(robot_name)
robot = Robot()
timestep = int(robot.getBasicTimeStep())

# Initializing motors
motors = []
for name in model.getMotorsNames():
    motors.append(robot.getDevice(name))

# Initializing sensors
sensors = []
for name in model.getSensorsNames():
    sensors.append(robot.getDevice(name))
    sensors[-1].enable(timestep)

with open('robot_data.csv', 'w') as output_file:
    logger = csv.DictWriter(output_file, ["t", "variable", "order", "source", "value"])
    logger.writeheader()

    t = 0.0  # [s]
    while robot.step(timestep) != -1:
        nb_joints = model.getNbJoints()
        q = np.zeros(nb_joints)
        for i in range(nb_joints):
            motors[i].setPosition(targets[i])
            q[i] = sensors[i].getValue()
        t += timestep / 10**3
